@@ -211,10 +211,10 @@ class AthenaClient:
     def save_data(self, data, file_name, s3_path):
         """Returns records from a table"""
         try:
-            d = data.to_dict(orient='records')
-            print(d)
+            d = json.dumps(data.to_dict(orient='records'))
             payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role, "file_name": file_name,
                                   "s3_bucket": s3_path, "data": d})
+            print(payload)
             r = requests.post(self._ccf_services_host + API_SAVE_DATA_TO_S3, data=payload, headers=HEADERS,
                               cookies=dict(sessionId=self._access_token))
             response = r.json()
